@@ -12,6 +12,8 @@ def get_args():
     return parser.parse_args()
 
 
-def main(args):
+def main():
+    args = get_args()
     client = Client(address=args.address)
-    print(json.dumps(client.statistics(), indent=4))
+    print(json.dumps(client.scheduler_status(), indent=4))
+    client.disconnect()
\ No newline at end of file
