@@ -4,6 +4,7 @@ import multiprocessing
 import queue
 import signal
 import threading
+import time
 from queue import Queue
 from typing import Callable, Dict, Optional
 
@@ -103,6 +104,7 @@ class Worker(multiprocessing.get_context("spawn").Process):
             bind_or_connect="connect",
             address=internal_channel,
             callback=self.__on_connector_receive,
+            daemonic=False,
         )
         self._agent = Agent(
             stop_event=self._stop_event,
@@ -138,8 +140,15 @@ class Worker(multiprocessing.get_context("spawn").Process):
 
             function = self._cached_functions[task.function_id]
             args, kwargs = self._serializer.deserialize_arguments(task.function_args)
-            result = self._serializer.serialize_result(function(*args, **kwargs))
-            self._agent_connector.send(MessageType.TaskResult, TaskResult(task.task_id, TaskStatus.Success, result))
+
+            begin = time.monotonic()
+            result = function(*args, **kwargs)
+            duration = time.monotonic() - begin
+
+            result_bytes = self._serializer.serialize_result(result)
+            self._agent_connector.send(
+                MessageType.TaskResult, TaskResult(task.task_id, TaskStatus.Success, duration, result_bytes)
+            )
 
         except Exception as e:
             logging.exception(f"{self.get_prefix()} error when processing {task=}:")
